@@ -1,4 +1,5 @@
 # flake8: noqa: F401
 from pvxarray._version import __version__
-from pvxarray.accessor import PyVistaRectilinearGridAccessor, PyVistaStructuredGridAccessor
+from pvxarray.accessor import PyVistaAccessor
+from pvxarray.errors import DataCopyWarning
 from pvxarray.report import Report
